@@ -1,10 +1,11 @@
 from asyncpg_trek._backend import SupportsBackend
 from asyncpg_trek._run import execute, plan
-from asyncpg_trek._types import Direction
+from asyncpg_trek._types import Direction, Operation
 
 __all__ = [
     "SupportsBackend",
     "plan",
     "execute",
     "Direction",
+    "Operation",
 ]
